@@ -43,11 +43,9 @@ from .filetransport import Client as File_Client
 # Avoid hanging the application if there's no server response
 timeout = 30
 
-NOT_MODIFIED = 304
 ONE_HOUR = 3600
 DEFAULT_NUM_ITEMS = 50
 DEFAULT_ITEM_LIMIT = 100
-TOO_MANY_REQUESTS = 429
 
 
 def build_url(base_url, path, args_dict=None):
@@ -451,8 +449,6 @@ class Zotero:
         Returns a JSON document
         """
         full_url = build_url(self.endpoint, request)
-        # The API doesn't return this any more, so we have to cheat
-        self.self_link = request
         # ensure that we wait if there's an active backoff
         self._check_backoff()
         # don't set locale if the url already contains it
@@ -485,6 +481,8 @@ class Zotero:
                 timeout=timeout,
             )
             self.request.encoding = "utf-8"
+            # The API doesn't return this any more, so we have to cheat
+            self.self_link = self.request.url
         except httpx.UnsupportedProtocol:
             # File URI handler logic
             fc = File_Client()
@@ -518,15 +516,12 @@ class Zotero:
                 fragment = f"{parsed[2]}?{parsed[4]}"
                 extracted[key] = fragment
             # add a 'self' link
-            parsed = list(urlparse(self.self_link))
-            # strip 'format' query parameter
-            stripped = "&".join(
-                ["=".join(p) for p in parse_qsl(parsed[4])[:2] if p[0] != "format"],
-            )
-            # rebuild url fragment
-            # this is a death march
+            parsed = urlparse(str(self.self_link))
+            # strip 'format' query parameter and rebuild query string
+            query_params = [(k, v) for k, v in parse_qsl(parsed.query) if k != "format"]
+            # rebuild url fragment with just path and query (consistent with other links)
             extracted["self"] = urlunparse(
-                [parsed[0], parsed[1], parsed[2], parsed[3], stripped, parsed[5]],
+                ("", "", parsed.path, "", urlencode(query_params), "")
             )
         except KeyError:
             # No links present, because it's a single item
@@ -572,7 +567,7 @@ class Zotero:
             )
             if backoff:
                 self._set_backoff(backoff)
-            return req.status_code == NOT_MODIFIED
+            return req.status_code == httpx.codes.NOT_MODIFIED
         # Still plenty of life left in't
         return False
 
@@ -1647,7 +1642,7 @@ def error_handler(zot, req, exc=None):
 
     if error_codes.get(req.status_code):
         # check to see whether its 429
-        if req.status_code == TOO_MANY_REQUESTS:
+        if req.status_code == httpx.codes.TOO_MANY_REQUESTS:
             # try to get backoff or delay duration
             delay = req.headers.get("backoff") or req.headers.get("retry-after")
             if not delay:
